@@ -3,12 +3,11 @@ package Spike;
 use strict;
 use warnings;
 
-our $VERSION = 2.0003;
+our $VERSION = 2.0004;
 
-use 5.14.0;
+use 5.10.1;
 
 use Plack 1.0030;
-use Syntax::Feature::Try 1.005;
 use List::Util 1.45;
 use File::ShareDir;
 
@@ -20,7 +19,7 @@ __END__
 
 =head1 NAME
 
-Spike-2.0 - simple L<Plack::Request>-based web framework
+Spike-2.0 - Simple L<Plack::Request>-based web framework
 
 =head1 SYNOPSIS
 
@@ -54,7 +53,6 @@ Spike-2.0 - simple L<Plack::Request>-based web framework
     package DeadBeef::Site;
 
     use base qw(Spike);
-    use HTTP::Status qw(:constants);
 
     sub startup {
         my $self = shift;
@@ -68,11 +66,11 @@ Spike-2.0 - simple L<Plack::Request>-based web framework
                 my ($req, $res) = @_;
                 # place code here
             })
-            ->error(HTTP_NOT_FOUND() => sub {
+            ->error(404 => sub {
                 my ($req, $res) = @_;
                 # place code here
             })
-            ->error(HTTP_INTERNAL_SERVER_ERROR() => sub {
+            ->error(500 => sub {
                 my ($req, $res) = @_;
                 # place code here
             })
