@@ -3,8 +3,6 @@ package Spike::Site::Router;
 use strict;
 use warnings;
 
-use syntax 'try';
-
 use base qw(Spike::Site::Handler);
 
 use Spike::Error;
@@ -12,12 +10,16 @@ use Spike::Site::Router::Route;
 use Spike::Cache;
 
 use Carp;
+
 use HTTP::Status qw(:constants);
 use Plack::MIME;
+
 use POSIX qw(strftime);
 use Date::Parse;
+
 use List::Util qw(first uniq);
 use List::MoreUtils qw(zip);
+use Scalar::Util qw(blessed);
 
 sub route { (shift->{route} ||= Spike::Site::Router::Route->new)->route(@_) }
 
@@ -29,9 +31,21 @@ sub config {
     return $config;
 }
 
+sub new {
+    my $proto = shift;
+    my $class = ref $proto || $proto;
+
+    my $self = $class->SUPER::new;
+
+    $self->startup;
+    $self->_init_config;
+
+    return $self;
+}
+
 sub cache {
     my $self = shift;
-    my $config = $self->config->spike_site_router;
+    my $config = $self->config->site_route_cache;
 
     return $self->{cache} ||= Spike::Cache->new(
         name          => 'Route cache',
@@ -61,13 +75,6 @@ sub _init_config {
         for keys %defaults;
 }
 
-sub init {
-    my $self = shift;
-
-    $self->_init_config;
-    $self->startup;
-}
-
 sub _find_handlers {
     my ($self, $route) = @_;
 
@@ -165,20 +172,28 @@ sub handler {
     my ($self, $req, $res) = @_;
 
     my $path = $req->safe_path;
+
+    my @methods = $self->debug &&
+        $self->_try_static($req, $res, $path) ? qw(GET) : ();
+
     my @handlers = $self->cache->get($path);
 
     if (!@handlers) {
         my ($found, $last_found) = $self->route->find($path);
-        @handlers = ($found, $self->_find_handlers($found || $last_found));
+
+        @handlers = (
+            $found,
+            $self->_find_handlers($found || $last_found),
+            [ split m!/!, $path ],
+        );
 
         $self->cache->store($path, @handlers);
     }
 
-    my ($route, $prepare, $finalize, $errors, $names) = @handlers;
+    my ($route, $prepare, $finalize, $errors, $names, $values) = @handlers;
 
-    $req->_bind_named_url_parameters(zip @$names, @{[ split m!/!, $path ]});
+    $req->_bind_named_url_parameters(zip @$names, @$values);
 
-    my @methods = $self->debug && $self->_try_static($req, $res, $path) ? qw(GET) : ();
     my $handler;
 
     if ($route) {
@@ -189,7 +204,7 @@ sub handler {
     if (!$handler) {
         if (@methods) {
             $self->_handle_error($req, $res, new Spike::Error::HTTP(
-                HTTP_METHOD_NOT_ALLOWED, allow => join(', ', uniq @methods)
+                HTTP_METHOD_NOT_ALLOWED, allow => join(', ', uniq @methods),
             ), $errors);
         }
         else {
@@ -198,27 +213,35 @@ sub handler {
         return;
     }
 
-    try {
+    eval {
         $finalize->($req, $res,
             $handler->($req, $res,
                 $prepare->($req, $res)
             )
         );
-    }
-    catch (Spike::Error::HTTP_OK $error) {
-        throw $error;
-    }
-    catch (Spike::Error::HTTP $error) {
-        carp "HTTP error: status=".$error->value.", text=\"".$error->text."\"";
-        $self->_handle_error($req, $res, $error, $errors);
-    }
-    catch (Spike::Error $error) {
-        carp "Error: class=".ref($error).", text=\"".$error->text."\"";
-        $self->_handle_error($req, $res, $error, $errors);
-    }
-    catch ($error) {
-        carp $error;
-        $self->_handle_error($req, $res, HTTP_INTERNAL_SERVER_ERROR, $errors);
+    };
+    if (my $error = $@) {
+        if (blessed $error) {
+            if ($error->isa('Spike::Error::HTTP_OK')) {
+                throw $error;
+            }
+            elsif ($error->isa('Spike::Error::HTTP')) {
+                carp "HTTP error: status=".$error->value.", text=\"".$error->text."\"";
+                $self->_handle_error($req, $res, $error, $errors);
+            }
+            elsif ($error->isa('Spike::Error')) {
+                carp "Error: class=".ref($error).", text=\"".$error->text."\"";
+                $self->_handle_error($req, $res, $error, $errors);
+            }
+            else {
+                carp "Error: class=".ref($error).", text=\"".($error->can('text') ? $error->text : "$error")."\"";
+                $self->_handle_error($req, $res, HTTP_INTERNAL_SERVER_ERROR, $errors);
+            }
+        }
+        else {
+            carp $error;
+            $self->_handle_error($req, $res, HTTP_INTERNAL_SERVER_ERROR, $errors);
+        }
     }
 }
 
