@@ -8,50 +8,6 @@ use base qw(Spike::Tree);
 use List::Util qw(first any);
 use HTTP::Status qw(:constants);
 
-sub childs {
-    my ($self, $filter) = @_;
-
-    my @ordered = ([], [], [], []);
-
-    my $has_filter = defined $filter && length $filter;
-
-    for my $child ($self->SUPER::childs) {
-        my $name = $child->name;
-
-        if ($name eq '*') {
-            push @{$ordered[3]}, $child;
-        }
-        elsif ($name =~ m!^#!) {
-            my $rule = $child->rule;
-
-            if (!$has_filter || !$rule || $self->check_rule($rule, $filter)) {
-                push @{$ordered[$rule ? 1 : 2]}, $child;
-            }
-        }
-        elsif (!$has_filter || $filter eq $name) {
-            push @{$ordered[0]}, $child;
-        }
-    }
-
-    return map { @$_ } @ordered;
-}
-
-sub check_rule {
-    my ($self, $rule, $value) = @_;
-
-    if (ref $rule eq 'CODE') {
-        return $rule->($_ = $value);
-    }
-    elsif (ref $rule eq 'ARRAY') {
-        return any { $_ eq $value } @$rule;
-    }
-    elsif (ref $rule eq 'Regexp') {
-        return $value =~ m!^(?:$rule)$!;
-    }
-
-    return !1;
-}
-
 sub route {
     my ($self, $path) = splice @_, 0, 2;
 
@@ -67,8 +23,7 @@ sub route {
     my $child = first {
         $_->name eq $first &&
         ($_->rule || $fake_rule) == ($rule || $fake_rule)
-    }
-    $self->childs;
+    } $self->childs;
 
     if (!$child) {
         $child = $self->new($first);
@@ -80,6 +35,48 @@ sub route {
     return $child->route($path, @_);
 }
 
+sub _check_rule {
+    my ($self, $rule, $value) = @_;
+
+    if (ref $rule eq 'CODE') {
+        return $rule->($_ = $value);
+    }
+    elsif (ref $rule eq 'ARRAY') {
+        return any { $_ eq $value } @$rule;
+    }
+    elsif (ref $rule eq 'Regexp') {
+        return $value =~ m!^(?:$rule)$!;
+    }
+
+    return !1;
+}
+
+sub _find {
+    my ($self, $part) = @_;
+
+    my @ordered = ([], [], []);
+
+    for my $child ($self->childs) {
+        my $name = $child->name;
+
+        if ($name eq '*') {
+            push @{$ordered[2]}, $child;
+        }
+        elsif ($name =~ m!^#!) {
+            my $rule = $child->rule;
+
+            if (!$rule || $self->_check_rule($rule, $part)) {
+                push @{$ordered[$rule ? 0 : 1]}, $child;
+            }
+        }
+        elsif ($name eq $part) {
+            return $child;
+        }
+    }
+
+    return $ordered[0][0] || $ordered[1][0] || $ordered[2][0] || ();
+}
+
 sub find {
     my ($self, $path) = @_;
 
@@ -89,7 +86,7 @@ sub find {
 
     return $self if !length $first;
 
-    return $_->find($path) for $self->childs($first);
+    return $_->find($path) for $self->_find($first);
 
     return wantarray ? (undef, $self) : ();
 }
