@@ -39,9 +39,10 @@ sub startup {
         });
 }
 
-sub cleanup {
+sub clean {
     my $self = shift;
     delete $self->{$_} for qw(stash);
+    $self->SUPER::clean;
 }
 
 1;
